@@ -1,38 +1,39 @@
 package Dist::Zilla::PluginBundle::Author::IOANR;
-$Dist::Zilla::PluginBundle::Author::IOANR::VERSION = '0.006';
+$Dist::Zilla::PluginBundle::Author::IOANR::VERSION = '1.162690';
 # ABSTRACT: Build dists the way IOANR likes
 use v5.12;
 use Moose;
 use List::Util 1.33 'any';
 use Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes 0.107;
 use Dist::Zilla::Plugin::ContributorsFile;
-use Dist::Zilla::Plugin::ContributorsFromGit;
+use Dist::Zilla::Plugin::CopyFilesFromBuild;
 use Dist::Zilla::Plugin::Git;
+use Dist::Zilla::Plugin::Git::Contributors;
 use Dist::Zilla::Plugin::GitHub;
 use Dist::Zilla::Plugin::Meta::Contributors;
 use Dist::Zilla::Plugin::MetaData::BuiltWith;
 use Dist::Zilla::Plugin::ModuleBuildTiny;
+use Dist::Zilla::Plugin::MojibakeTests;
 use Dist::Zilla::Plugin::PodWeaver 4.000;
 use Dist::Zilla::Plugin::ReadmeFromPod;
-use Dist::Zilla::Plugin::CopyFilesFromBuild;
 use Dist::Zilla::Plugin::RunExtraTests;
 use Dist::Zilla::Plugin::Signature;
 use Dist::Zilla::Plugin::Test::CheckDeps;
-use Dist::Zilla::Plugin::Test::Pod::No404s;
-use Dist::Zilla::Plugin::Test::ReportPrereqs;
-use Dist::Zilla::Plugin::Test::CPAN::Meta::JSON;
-use Dist::Zilla::Plugin::Test::Pod::LinkCheck;
-use Dist::Zilla::Plugin::Test::Version;
 use Dist::Zilla::Plugin::Test::Compile;
+use Dist::Zilla::Plugin::Test::CPAN::Meta::JSON;
 use Dist::Zilla::Plugin::Test::DistManifest;
 use Dist::Zilla::Plugin::Test::EOL;
 use Dist::Zilla::Plugin::Test::Kwalitee;
 use Dist::Zilla::Plugin::Test::MinimumVersion;
-use Dist::Zilla::Plugin::MojibakeTests;
 use Dist::Zilla::Plugin::Test::NoTabs;
-use Dist::Zilla::Plugin::Test::Portability;
+use Dist::Zilla::Plugin::Test::Pod::LinkCheck;
 use Dist::Zilla::Plugin::Test::Pod::No404s;
+use Dist::Zilla::Plugin::Test::Pod::No404s;
+use Dist::Zilla::Plugin::Test::Portability;
+use Dist::Zilla::Plugin::Test::ReportPrereqs;
 use Dist::Zilla::Plugin::Test::Synopsis;
+use Dist::Zilla::Plugin::Test::UnusedVars;
+use Dist::Zilla::Plugin::Test::Version;
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -93,9 +94,10 @@ sub configure {
 
     my @plugins = (
         'AutoPrereqs',
+        'AutoVersion',
         ['ChangelogFromGit::CPAN::Changes' => $change_opts],
         'ContributorsFile',
-        'ContributorsFromGit',
+        ['Git::Contributors' => {order_by => 'commits'}],
         ['CopyFilesFromBuild' => {copy => [qw/README.md LICENSE/]}],
         'ExecDir',
         [
@@ -111,7 +113,6 @@ sub configure {
                 exclude_match    => '(Changes|README.md|LICENSE)$',
             }
         ],
-        'Git::NextVersion',
         'GitHub::Meta',
         'License',
         'Manifest',
@@ -131,18 +132,18 @@ sub configure {
         'Test::DistManifest',
         'Test::EOL',
         ['Test::Kwalitee' => { skiptest => [qw/has_readme/]}],
-        'Test::MinimumVersion',
+        'Test::MinimumVersion', # TODO only checks META.yml, which we don't have
         'Test::NoTabs',
         'Test::Pod::LinkCheck',
         'Test::Pod::No404s',
         'Test::Portability',
         'Test::ReportPrereqs',
+        'Test::UnusedVars',
         'Test::Synopsis',
         'Test::Version',
         'TestRelease',
     );
 
-    # Test::UnusedVars
     # Test::Perl::Critic
     # PodCoverageTests
     # PodSyntaxTests
@@ -178,7 +179,7 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Ioan Rogers Романов Сергей
+=for :stopwords Ioan Rogers
 
 =head1 NAME
 
@@ -186,77 +187,7 @@ Dist::Zilla::PluginBundle::Author::IOANR - Build dists the way IOANR likes
 
 =head1 VERSION
 
-version 0.006
-
-=head1 DESCRIPTION
-
-Equivalent to the following C<dist.ini>
-
-  [Git::GatherDir]
-  include_dotfiles = 1
-
-  [Git::Check]
-  allow_dirty = README.mkdn
-  allow_dirty = dist.ini
-  allow_dirty = Changes
-
-  [PodWeaver]
-  config_plugin = @Author::IOANR
-
-  [MetaData::BuiltWith]
-  show_config = 1
-
-  [ReadmeAnyFromPod]
-  type = markdown
-  filename => README.mkdn
-  location => build
-
-  [ChangelogFromGit::CPAN::Changes]
-  file_name       = Changes
-  tag_regexp      = ^v(\d+\.\d+\.\d+)$
-  max_age         = 730
-  exclude_message = ^(dist.ini|v(\d+\.?)+)
-  group_by_author = 1
-
-  [ContributorsFile]
-  [ContributorsFromGit]
-  [ExecDir]
-  [Git::NextVersion]
-  [License]
-  [Manifest]
-  [Meta::Contributors]
-  [MetaJSON]
-  [ModuleBuildTiny]
-  [PkgVersion]
-  [PruneCruft]
-  [RunExtraTests]
-  [ShareDir]
-  [Signature]
-  [Test::CheckDeps]
-  [Test::Pod::No404s]
-  [Test::ReportPrereqs]
-  [TestRelease]
-
-  [GitHub]
-  metacpan = 1
-
-  [TestingMania]
-  disable => MetaTests
-  disable => Test::Kwalitee
-  disable => Test::Perl::Critic
-
-  [Git::CommitBuild]
-  release_branch  => 'last_release',
-  release_message => 'Release %v',
-
-  [Git::Tag]
-  signed = 1
-  branch = last_release
-
-  [ConfirmRelease]
-  [Git::Commit]
-  [Git::Push]
-  [UploadToCPAN]
+version 1.162690
 
 =head1 OPTIONS
 
@@ -314,7 +245,7 @@ Ioan Rogers <ioanr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Ioan Rogers.
+This software is Copyright (c) 2016 by Ioan Rogers.
 
 This is free software, licensed under:
 
